#ifndef OBGNOME_APP_H
#define OBGNOME_APP_H 1

#include <gnome.h>
#include "obgtk/obgtk.h"

@interface Gnome_App : Gtk_App
- initApp:(char *)app_id
         :(struct argp *)app_parser
	 :(int)argc
	 :(char **)argv
	 :(unsigned int)flags
	 :(int *)arg_index;
@end

#endif /* OBGNOME_APP_H */
